/* eslint-env es6 */

var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var today = helpers.getToday();
var monthAgo = helpers.getMonthAgo();

var launchesByOS = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(today)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.$os', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

var launchesByCompassVersion = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(today)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.app version', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

function getLaunchesVersionData(secret) {
  var str = mixpanel.mixpanelJQL(secret, launchesByCompassVersion);
  var str2 = helpers.transformStreamJQL(str);
  return str2;
}

function getLaunchesOsData(secret) {
  var str = mixpanel.mixpanelJQL(secret, launchesByOS);
  var str2 = helpers.transformStreamJQL(str);
  return str2;
}

module.exports = {
  getLaunchesOsData: getLaunchesOsData,
  getLaunchesVersionData: getLaunchesVersionData
};
