/* eslint-env es6 */

var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var today = helpers.getToday();
var monthAgo = helpers.getMonthAgo();

var samplingQuery = `function main() {
  function getDay(event) {
    return (new Date(event.time)).toISOString().split('T')[0];
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(today)}'
  })
  .filter(function(event) {
    return event.name === "Schema sampled";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .map(function(item) {
    var sampleTime = item.properties['total sample time'] + item.properties['total analysis time'];
    return {
      'date': getDay(item),
      'sampleTime': sampleTime
    };
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var i;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = [];
        }
        for (var j = 0; j < accumulators[i][date].length; ++j) {
          obj[date].push(accumulators[i][date][j]);
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      if (obj[items[i].date] === undefined) {
        obj[items[i].date] = [];
      }
      obj[items[i].date].push(items[i].sampleTime);
    }
    return obj;
  });
}`;

function getSamplingData(secret) {
  var str = mixpanel.mixpanelJQL(secret, samplingQuery);
  var str2 = helpers.transformStreamJQL(str);
  return str2;
}

module.exports = getSamplingData;
